# PreFab Models

`PreFab` accommodates unique *predictor* and *corrector* models for each photonic foundry, regularly updated based on recent fabrication data.

| Foundry | Process | Latest Version | Latest Dataset | Type | Full Name | Status | Usage |
| ------- | ------- | -------------- | -------------- | ---- | --------- |------- | ----- |
| ANT | NanoSOI | v5 (Jun 3 2023) | v4 (Apr 12 2023) | Predictor | p_ANT_NanoSOI_v5_d4 | Beta | Open |
| ANT | NanoSOI | v5 (Jun 3 2023) | v4 (Apr 12 2023) | Corrector | c_ANT_NanoSOI_v5_d4 | Beta | Open |

*New models and foundries are regularly added. Usage may change. For additional foundry and process models, feel free to contact us or raise an issue.*
